# beforerr


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Python utils for different packages

[![PyPI](https://img.shields.io/pypi/v/beforerr.png)](https://pypi.org/project/beforerr/)
[![Pixi
Badge](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/prefix-dev/pixi/main/assets/badge/v0.json)](https://pixi.sh)
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet.png)](https://pdm-project.org)

## Install

``` sh
pip install beforerr
```
